@@ -1,22 +1,17 @@
 #!/usr/bin/env python
 import logging
-import os
-import sys
-from os.path import abspath, dirname
+from pathlib import Path
 
-import django
-from django.conf import settings
-from django.test.runner import DiscoverRunner
-from edc_test_utils import DefaultTestSettings
+from edc_test_utils import DefaultTestSettings, func_main
 
 app_name = "edc_identifier"
-base_dir = dirname(abspath(__file__))
+base_dir = Path(__file__).absolute().parent
 
-DEFAULT_SETTINGS = DefaultTestSettings(
+project_settings = DefaultTestSettings(
     calling_file=__file__,
     APP_NAME=app_name,
     BASE_DIR=base_dir,
-    ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
+    SUBJECT_VISIT_MODEL="edc_visit_tracking.subjectvisit",
     INSTALLED_APPS=[
         "django.contrib.admin",
         "django.contrib.auth",
@@ -26,12 +21,17 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "django.contrib.staticfiles",
         "django.contrib.sites",
         "django_crypto_fields.apps.AppConfig",
+        "edc_action_item.apps.AppConfig",
+        "edc_device.apps.AppConfig",
         "edc_randomization.apps.AppConfig",
         "edc_sites.apps.AppConfig",
+        "edc_notification.apps.AppConfig",
         "edc_protocol.apps.AppConfig",
         "edc_appointment.apps.AppConfig",
+        "edc_metadata.apps.AppConfig",
         "edc_registration.apps.AppConfig",
-        "edc_identifier.apps.EdcDeviceAppConfig",
+        "edc_visit_schedule.apps.AppConfig",
+        "edc_visit_tracking.apps.AppConfig",
         "edc_identifier.apps.AppConfig",
     ],
     add_dashboard_middleware=True,
@@ -39,11 +39,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
 
 
 def main():
-    if not settings.configured:
-        settings.configure(**DEFAULT_SETTINGS)
-    django.setup()
-    failures = DiscoverRunner(failfast=True).run_tests([f"{app_name}.tests"])
-    sys.exit(failures)
+    func_main(project_settings, f"{app_name}.tests")
 
 
 if __name__ == "__main__":
